@@ -34,7 +34,7 @@
           : { ( @_ == 1 ) ? %{ $_[0] } : @_ };
         my $no_build = delete $args->{__no_BUILD__};
 
-        # Initialize attributes
+        # Attribute: cards
         if ( exists $args->{"cards"} ) {
             (
                 do {
@@ -57,12 +57,13 @@
                     $ok;
                 }
               )
-              or require Carp
-              && Carp::croak(
-                sprintf "Type check failed in constructor: %s should be %s",
-                "cards", "CardArray" );
+              or Acme::Mitey::Cards::Mite::croak
+              "Type check failed in constructor: %s should be %s", "cards",
+              "CardArray";
             $self->{"cards"} = $args->{"cards"};
         }
+
+        # Attribute: owner
         if ( exists $args->{"owner"} ) {
             do {
 
@@ -87,18 +88,16 @@
                       )
                 );
               }
-              or require Carp
-              && Carp::croak(
-                sprintf "Type check failed in constructor: %s should be %s",
-                "owner", "Str|Object" );
+              or Acme::Mitey::Cards::Mite::croak
+              "Type check failed in constructor: %s should be %s", "owner",
+              "Str|Object";
             $self->{"owner"} = $args->{"owner"};
         }
 
         # Enforce strict constructor
         my @unknown = grep not(/\A(?:cards|owner)\z/), keys %{$args};
         @unknown
-          and require Carp
-          and Carp::croak(
+          and Acme::Mitey::Cards::Mite::croak(
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
@@ -193,9 +192,8 @@
                       )
                 );
               }
-              or require Carp
-              && Carp::croak(
-                sprintf "Type check failed in %s: value should be %s",
+              or Acme::Mitey::Cards::Mite::croak(
+                "Type check failed in %s: value should be %s",
                 "accessor", "Str|Object" );
             $_[0]{"owner"} = $_[1];
             $_[0];
